package com.mortals.xhx.module.staff.service.impl;

import com.mortals.framework.model.PageInfo;
import com.mortals.framework.util.SecurityUtil;
import com.mortals.xhx.base.system.user.model.UserEntity;
import com.mortals.xhx.base.system.user.service.UserService;
import org.springframework.beans.BeanUtils;

import java.util.function.Function;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.staff.dao.StaffDao;
import com.mortals.xhx.module.staff.model.StaffEntity;
import com.mortals.xhx.module.staff.service.StaffService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.ObjectUtils;

/**
 * StaffService
 * 代办帮办人员 service实现
 *
 * @author zxfei
 * @date 2025-05-08
 */
@Service("staffService")
@Slf4j
public class StaffServiceImpl extends AbstractCRUDServiceImpl<StaffDao, StaffEntity, Long> implements StaffService {
    @Autowired
    private UserService userService;


    @Override
    protected void saveBefore(StaffEntity entity, Context context) throws AppException {
        //查询登录名是否存在
        boolean bool = userService.existUser(entity.getLoginName(), this.getContextUserId(context));
        if (bool) throw new AppException("登录名已存在！");

        // userService.doCheckUser(entity.getLoginName(), entity.getLoginPwd());
        super.saveBefore(entity, context);
    }

    @Override
    protected void saveAfter(StaffEntity entity, Context context) throws AppException {
        //创建用户
        UserEntity userEntity = new UserEntity();
        userEntity.initAttrValue();
        userEntity.setLoginName(entity.getLoginName());
        String password = null;
        try {
            password = SecurityUtil.md5DoubleEncoding(entity.getLoginPwd());
        } catch (Exception e) {
            throw new RuntimeException(e);
        }

        userEntity.setLoginPwd(password);
        userEntity.setRealName(entity.getRealName());
        userEntity.setMobile(entity.getPhoneNumber());
        userEntity.setPhone(entity.getPhoneNumber());
        userEntity.setCustomerId(entity.getId());

        userService.getUserDao().insert(userEntity);
        entity.setUserId(userEntity.getId());

        super.saveAfter(entity, context);
    }


    @Override
    protected void updateBefore(StaffEntity entity, Context context) throws AppException {
        //查询登录名是否存在
        boolean bool = userService.existUser(entity.getLoginName(), entity.getUserId());
        if (bool) throw new AppException("登录名已存在！");

        super.updateBefore(entity, context);
    }

    @Override
    protected void updateAfter(StaffEntity entity, Context context) throws AppException {
        //更新用户
        UserEntity userEntity = userService.get(entity.getUserId(), context);
        if(!ObjectUtils.isEmpty(userEntity)){
            userEntity.setLoginName(entity.getLoginName());
            String password = null;
            try {
                password = SecurityUtil.md5DoubleEncoding(entity.getLoginPwd());
            } catch (Exception e) {
                throw new RuntimeException(e);
            }

            userEntity.setLoginPwd(password);
            userEntity.setRealName(entity.getRealName());
            userEntity.setMobile(entity.getPhoneNumber());
            userEntity.setPhone(entity.getPhoneNumber());
            userService.getUserDao().update(userEntity);
        }

        super.updateAfter(entity, context);
    }
}